CREATE OR REPLACE PROCEDURE INTEGRACAO_PACIENTE
   (P_CDPACIENTE              IN PACIENTE.CDPACIENTE%TYPE,
    P_NMPACIENTE              IN PACIENTE.NMPACIENTE%TYPE,
    P_IDSEXOPACI              IN PACIENTE.IDSEXOPACI%TYPE,
    P_DTNASCPACI              IN PACIENTE.DTNASCPACI%TYPE,
    P_CDLEITO                 IN LEITO.CDLEITO%TYPE,
    P_CDEQUIMED               IN EQUIMEDI.CDEQUIMED%TYPE,
    P_CDSERPADDIE             IN PADRAOSERV.CDSERPADDIE%TYPE,
    P_DTINTERNA               IN INTERNAC.DTINTERNA%TYPE,
    P_DTALTA                  IN INTERNAC.DTALTA%TYPE,
    P_CDALA                   IN ALA.CDALA%TYPE,
    P_CDANDAR                 IN ANDAR.CDANDAR%TYPE)
IS
   V_CDFILIAL      VARCHAR2(04) := '0001';
   V_EXIST         VARCHAR2(20);
   V_CDPACIENTE    VARCHAR2(12);
   V_CDLEITO       VARCHAR2(12);
   V_DTPRESDIET    PRESDIET.DTPRESDIET%TYPE;
   V_SYSDATE       PRESDIET.DTPRESDIET%TYPE;
   V_IDPACIENT     VARCHAR2(1) := '0';
   V_CONST_N       VARCHAR2(1) := 'N';
   V_CONST_S       VARCHAR2(1) := 'S';
   V_IDOBSPRESC    VARCHAR2(1);
   V_DSOBSPRESC    LONG RAW;
   V_IDDIETAESP    VARCHAR2(1);
   V_CDTIPOLAUDO   VARCHAR2(3);
   V_DSLAUDPRES    LONG RAW;

BEGIN
  INSERT INTO USR_LOG_INTEGRACAO(CDPACIENTE, NMPACIENTE, IDSEXOPACI, DTNASCPACI, CDLEITO, CDEQUIMED,
                             CDSERPADDIE, DTINTERNA, DTALTA, CDALA, CDANDAR, DTHREXEC)
  VALUES (P_CDPACIENTE, P_NMPACIENTE, P_IDSEXOPACI, P_DTNASCPACI, P_CDLEITO, P_CDEQUIMED,
          P_CDSERPADDIE, P_DTINTERNA, P_DTALTA, P_CDALA, P_CDANDAR, SYSDATE);
  COMMIT;

  /*VERIFICAR SE J EXISTE O PACIENTE CADASTRADO*/
  BEGIN
    SELECT CDPACIENTE
    INTO V_EXIST
    FROM PACIENTE
    WHERE (CDFILIAL   = V_CDFILIAL) AND
          (CDPACIENTE = P_CDPACIENTE);
  EXCEPTION
    WHEN NO_DATA_FOUND THEN
    INSERT INTO PACIENTE(CDFILIAL, CDPACIENTE, NMPACIENTE, NMSOBRNOME,
                         IDSEXOPACI, DTNASCPACI, IDPACIENT)
    VALUES (V_CDFILIAL, P_CDPACIENTE, P_NMPACIENTE,
            SUBSTR (P_NMPACIENTE,INSTR(P_NMPACIENTE,' ',-1,1)+1,15),
            P_IDSEXOPACI, P_DTNASCPACI, V_IDPACIENT);
  END;

  /*VERIFICAR SE J EXISTE O ANDAR CADASTRADO*/
  BEGIN
      SELECT CDANDAR
      INTO V_EXIST
      FROM ANDAR
      WHERE (CDFILIAL = V_CDFILIAL)  AND
            (CDANDAR  = P_CDANDAR);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
       INSERT INTO ANDAR(CDFILIAL, CDANDAR, NMANDAR)
       VALUES (V_CDFILIAL, P_CDANDAR, P_CDANDAR);
   END;

   /*VERIFICAR SE J EXISTE O ALA CADASTRADA*/
   BEGIN
      SELECT CDALA
      INTO V_EXIST
      FROM ALA
      WHERE (CDFILIAL = V_CDFILIAL)  AND
            (CDALA    = P_CDALA);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
       INSERT INTO ALA(CDFILIAL, CDALA, NMALA)
       VALUES (V_CDFILIAL, P_CDALA, P_CDALA);
   END;

   /*VEIFICAR SE EXISTE CADASTRADA A LIGAO DE ALA E ANDAR*/
   BEGIN
      SELECT CDALA
      INTO V_EXIST
      FROM ALANDAR
      WHERE (CDFILIAL = V_CDFILIAL)  AND
            (CDALA    = P_CDALA)     AND
            (CDANDAR  = P_CDANDAR);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
       INSERT INTO ALANDAR(CDFILIAL, CDALA, CDANDAR)
       VALUES (V_CDFILIAL, P_CDALA, P_CDANDAR);
   END;

   /*VERIFICAR SE J EXISTE O LEITO CADASTRADO*/
   BEGIN
      SELECT CDLEITO
      INTO V_EXIST
      FROM LEITO
      WHERE (CDFILIAL = V_CDFILIAL)  AND
            (CDLEITO  = P_CDLEITO);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
       INSERT INTO LEITO(CDFILIAL, CDLEITO, NMLEITO, CDANDAR, CDALA)
       VALUES (V_CDFILIAL, P_CDLEITO, P_CDLEITO, P_CDANDAR, P_CDALA);
   END;

   /*VERIFICAR SE J EXISTE A EQUIPE MDICA CADASTRADA*/
   BEGIN
      SELECT CDEQUIMED
      INTO V_EXIST
      FROM EQUIMEDI
      WHERE (CDFILIAL = V_CDFILIAL)  AND
            (CDEQUIMED  = P_CDEQUIMED);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
       INSERT INTO EQUIMEDI(CDFILIAL, CDEQUIMED, NMEQUIMED)
       VALUES (V_CDFILIAL, P_CDEQUIMED, P_CDEQUIMED);
   END;

   /*VERIFICAR SE J EXISTE O PADRAO DE INTERNACAO CADASTRAD0*/
   BEGIN
      SELECT CDSERPADDIE
      INTO V_EXIST
      FROM PADRAOSERV
      WHERE (CDSERPADDIE  = P_CDSERPADDIE);
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
       INSERT INTO PADRAOSERV(CDSERPADDIE, NMSERPADDIE)
       VALUES (P_CDSERPADDIE, P_CDSERPADDIE);
   END;

   /*VERIFICAR A TROCA DE LEITO*/

   BEGIN
     SELECT CDLEITO
     INTO V_CDLEITO
     FROM INTERNAC
     WHERE (CDFILIAL   = V_CDFILIAL)   AND
           (CDPACIENTE = P_CDPACIENTE) AND
           (DTINTERNA  = P_DTINTERNA);
   EXCEPTION
     WHEN NO_DATA_FOUND THEN
       V_CDLEITO := NULL;
   END;

   IF (V_CDLEITO IS NULL) THEN
     INSERT INTO INTERNAC (CDFILIAL, CDPACIENTE, DTINTERNA, DTALTA, CDEQUIMED,
                          CDSERPADDIE, CDLEITO)
     VALUES (V_CDFILIAL, P_CDPACIENTE, P_DTINTERNA, P_DTALTA, P_CDEQUIMED,
             P_CDSERPADDIE, P_CDLEITO);
   END IF;

   IF (V_CDLEITO <> P_CDLEITO) OR (NOT P_DTALTA IS NULL) THEN
     UPDATE INTERNAC
     SET CDLEITO = P_CDLEITO,
         DTALTA  = P_DTALTA
     WHERE (CDFILIAL   = V_CDFILIAL)   AND
           (CDPACIENTE = P_CDPACIENTE) AND
           (DTINTERNA  = P_DTINTERNA);

     IF (V_CDLEITO <> P_CDLEITO) THEN
         /*DESOCUPA O LEITO ANTERIOR*/
         UPDATE LEITO
         SET IDOCUPLEITO = V_CONST_N
         WHERE (CDFILIAL = V_CDFILIAL) AND
               (CDLEITO  = V_CDLEITO);

         /*GERAR NOVA PRESCRIO PARA O NOVO LEITO*/
         SELECT MAX(P.DTPRESDIET)
         INTO V_DTPRESDIET
         FROM PRESDIET P
         WHERE (P.CDFILIAL   = V_CDFILIAL)   AND
               (P.CDPACIENTE = P_CDPACIENTE) AND
               (P.DTPRESDIET BETWEEN P_DTINTERNA AND NVL(P_DTALTA,SYSDATE));

         V_SYSDATE := SYSDATE;
         INSERT INTO PRESDIET (CDFILIAL,CDPACIENTE,DTPRESDIET,CDDIETPAD,
                               DSPRESDIET,DSDADOCLIN,DSPRESMEDDIE,CDNIASNUTR,CDLEITO)
         SELECT CDFILIAL,CDPACIENTE, V_SYSDATE, CDDIETPAD,
                DSPRESDIET, DSDADOCLIN, DSPRESMEDDIE, CDNIASNUTR, P_CDLEITO
         FROM PRESDIET P
         WHERE (P.CDFILIAL   = V_CDFILIAL )  AND
               (P.CDPACIENTE = P_CDPACIENTE) AND
               (P.DTPRESDIET = V_DTPRESDIET);

         /*INCLUIR AS OBSERVAES - LAUDO*/

         BEGIN
           SELECT IDDIETAESP, CDTIPOLAUDO, DSLAUDPRES
           INTO V_IDDIETAESP, V_CDTIPOLAUDO, V_DSLAUDPRES
           FROM LAUDPRESC
           WHERE (CDFILIAL   = V_CDFILIAL)   AND
                 (CDPACIENTE = P_CDPACIENTE) AND
                 (DTPRESDIET = V_DTPRESDIET);
         EXCEPTION
            WHEN NO_DATA_FOUND THEN BEGIN
                V_IDDIETAESP  := NULL;
                V_CDTIPOLAUDO := NULL;
                V_DSLAUDPRES  := NULL;
            END;
         END;
         IF (NOT V_IDDIETAESP IS NULL) AND (NOT V_DSLAUDPRES IS NULL) THEN
           INSERT INTO LAUDPRESC (CDFILIAL, CDPACIENTE, DTPRESDIET, IDDIETAESP, CDTIPOLAUDO, DSLAUDPRES)
           VALUES (V_CDFILIAL, P_CDPACIENTE, V_SYSDATE , V_IDDIETAESP, V_CDTIPOLAUDO, V_DSLAUDPRES);
         END IF;

         /*OBSERVAO*/
         BEGIN
           SELECT IDOBSPRESC, DSOBSPRESC
           INTO V_IDOBSPRESC, V_DSOBSPRESC
           FROM OBSPRESC
           WHERE (CDFILIAL   = V_CDFILIAL)    AND
                 (CDPACIENTE = P_CDPACIENTE)  AND
                 (DTPRESDIET = V_DTPRESDIET);
         EXCEPTION
           WHEN NO_DATA_FOUND THEN BEGIN
              V_IDOBSPRESC := NULL;
              V_DSOBSPRESC := NULL;
           END;
         END;
         IF (NOT V_IDOBSPRESC IS NULL) AND (NOT V_DSOBSPRESC IS NULL) THEN
           INSERT INTO OBSPRESC (CDFILIAL, CDPACIENTE, DTPRESDIET, IDOBSPRESC, DSOBSPRESC)
           VALUES (V_CDFILIAL, P_CDPACIENTE, V_SYSDATE, V_IDOBSPRESC, V_DSOBSPRESC);
         END IF;

         /*OCORRNCIAS DA PRESCRIO*/
         FOR C_OCORPRESC IN (
         SELECT NROCORPRES, DTOCORPRES, IDOCORPRES, DSOCORPRES, VRCOMPLOCPRE
         FROM OCORPRESC
         WHERE (CDFILIAL   = V_CDFILIAL)   AND
               (CDPACIENTE = P_CDPACIENTE) AND
               (DTPRESDIET = V_DTPRESDIET)) LOOP
            INSERT INTO OCORPRESC (CDFILIAL, CDPACIENTE, DTPRESDIET, NROCORPRES,
                                   DTOCORPRES, IDOCORPRES, DSOCORPRES, VRCOMPLOCPRE)
            VALUES(V_CDFILIAL, P_CDPACIENTE, V_SYSDATE, C_OCORPRESC.NROCORPRES, C_OCORPRESC.DTOCORPRES,
                   C_OCORPRESC.IDOCORPRES, C_OCORPRESC.DSOCORPRES, C_OCORPRESC.VRCOMPLOCPRE);
         END LOOP;

     END IF;
   END IF;
   IF (NOT P_DTALTA IS NULL) THEN
     UPDATE LEITO
     SET IDOCUPLEITO = V_CONST_N
     WHERE (CDFILIAL = V_CDFILIAL) AND
           (CDLEITO  = P_CDLEITO);
   ELSE
     UPDATE LEITO
     SET IDOCUPLEITO = V_CONST_S
     WHERE (CDFILIAL = V_CDFILIAL) AND
           (CDLEITO  = P_CDLEITO);
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('INTEGRACAO_PACIENTE','4.11.113'); END;
/

